@@ -6,6 +6,7 @@ import tempfile
 import threading
 from contextlib import suppress
 from pathlib import Path
+from typing import Type
 
 from streamlink.compat import is_win32
 
@@ -26,7 +27,7 @@ class NamedPipeBase(abc.ABC):
     path: Path
 
     def __init__(self):
-        global _id
+        global _id  # noqa: PLW0603
         with _lock:
             _id += 1
             self.name = f"streamlinkpipe-{os.getpid()}-{_id}-{random.randint(0, 9999)}"
@@ -133,4 +134,8 @@ class NamedPipeWindows(NamedPipeBase):
             self.pipe = None
 
 
-NamedPipe = NamedPipePosix if not is_win32 else NamedPipeWindows
+NamedPipe: Type[NamedPipeBase]
+if not is_win32:
+    NamedPipe = NamedPipePosix
+else:
+    NamedPipe = NamedPipeWindows
