@@ -824,9 +824,11 @@ def log_current_arguments(session: Streamlink, parser: argparse.ArgumentParser):
                 sensitive.add(parg.argument_name(pname))
 
     log.debug("Arguments:")
+    seen = set()
     for action in parser._actions:
-        if not hasattr(args, action.dest):
+        if not hasattr(args, action.dest) or action.dest in seen:
             continue
+        seen.add(action.dest)
         value = getattr(args, action.dest)
         if action.default != value:
             name = next(  # pragma: no branch
@@ -861,10 +863,7 @@ def setup_logger_and_console(stream=sys.stdout, filename=None, level="info", jso
     console = ConsoleOutput(streamhandler.stream, json)
 
 
-def main():
-    error_code = 0
-    parser = build_parser()
-
+def setup(parser: ArgumentParser) -> None:
     setup_args(parser, ignore_unknown=True)
     # call argument set up as early as possible to load args from config files
     setup_config_args(parser, ignore_unknown=True)
@@ -902,6 +901,10 @@ def main():
 
     setup_signals()
 
+
+def run(parser: ArgumentParser) -> int:
+    error_code = 0
+
     if args.version_check or args.auto_version_check:
         try:
             check_version(force=args.version_check)
@@ -951,4 +954,11 @@ def main():
             + "Use -h/--help to see the available options or read the manual at https://streamlink.github.io",
         )
 
+    return error_code
+
+
+def main():
+    parser = build_parser()
+    setup(parser)
+    error_code = run(parser)
     sys.exit(error_code)
